@@ -1,5 +1,16 @@
+#![warn(
+    clippy::all,
+    clippy::correctness,
+    clippy::suspicious,
+    clippy::style,
+    clippy::complexity,
+    clippy::perf,
+    nonstandard_style
+)]
+
 use pyo3::{prelude::*, wrap_pyfunction, PyNativeType, Python};
 
+use crate::op::init_op_submodule;
 use crate::raster::init_raster_submodule;
 use crate::vector::init_vector_submodule;
 use crate::{collections::H3CompactedVec, polygon::Polygon};
@@ -7,6 +18,7 @@ use h3ron::{H3Cell, Index};
 
 mod collections;
 mod error;
+mod op;
 mod polygon;
 mod raster;
 mod transform;
@@ -36,6 +48,10 @@ fn h3ronpy(py: Python<'_>, m: &PyModule) -> PyResult<()> {
     init_raster_submodule(raster_submod)?;
     m.add_submodule(raster_submod)?;
 
+    let op_submod = PyModule::new(py, "op")?;
+    init_op_submodule(op_submod)?;
+    m.add_submodule(op_submod)?;
+
     Ok(())
 }
 
