@@ -31,3 +31,16 @@ def test_r_tiff_float32():
     assert len(df) > 100
     assert df.dtypes["h3index"] == "uint64"
     assert df.dtypes["value"] == "float32"
+
+
+def test_preserve_nan_without_nodata_value():
+    arr = np.array([[np.nan, 1.0], [np.nan, 1.0]], dtype=np.float32)
+    df = raster_to_dataframe(arr, [11.0, 1.0, 0.0, 10.0, 1.2, 0.2], 7, nodata_value=None)
+    assert df["value"].value_counts(dropna=False)[np.nan] > 100
+    assert df["value"].value_counts(dropna=False)[1.0] > 100
+
+
+def test_preserve_nan_with_nodata_value():
+    arr = np.array([[np.nan, 1.0], [np.nan, 1.0]], dtype=np.float32)
+    df = raster_to_dataframe(arr, [11.0, 1.0, 0.0, 10.0, 1.2, 0.2], 7, nodata_value=1.0)
+    assert df["value"].value_counts(dropna=False)[np.nan] > 100
